@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2003 Torrey T. Lyons. All Rights Reserved.
+ * Copyright (c) 2003-2004 Torrey T. Lyons. All Rights Reserved.
  *
  * Permission is hereby granted, free of charge, to any person obtaining a
  * copy of this software and associated documentation files (the "Software"),
@@ -23,7 +23,7 @@
  * holders shall not be used in advertising or otherwise to promote the sale,
  * use or other dealings in this Software without prior written authorization.
  */
-/* $XFree86: xc/programs/Xserver/hw/darwin/darwinKeyboard.h,v 1.2 2005/10/14 15:16:23 tsi Exp $ */
+/* $XFree86: xc/programs/Xserver/hw/darwin/darwinKeyboard.h,v 1.3 2007/04/03 00:21:07 tsi Exp $ */
 
 #ifndef DARWIN_KEYBOARD_H
 #define DARWIN_KEYBOARD_H 1
@@ -45,6 +45,8 @@ typedef struct darwinKeyboardInfo_struct {
     unsigned char modifierKeycodes[32][2];
 } darwinKeyboardInfo;
 
+void DarwinKeyboardReload(DeviceIntPtr pDev);
+unsigned int DarwinModeSystemKeymapSeed(void);
 Bool DarwinModeReadSystemKeymap(darwinKeyboardInfo *info);
 
 #endif /* DARWIN_KEYBOARD_H */
