@@ -1,4 +1,4 @@
-/* $XFree86: xc/programs/Xserver/hw/xfree86/common/compiler.h,v 3.108 2004/04/03 22:26:23 dawes Exp $ */
+/* $XFree86: xc/programs/Xserver/hw/xfree86/common/compiler.h,v 3.115 2006/02/20 00:14:37 dawes Exp $ */
 /*
  * Copyright 1990,91 by Thomas Roell, Dinkelscherben, Germany.
  *
@@ -22,7 +22,7 @@
  *
  */
 /*
- * Copyright (c) 1994-2003 by The XFree86 Project, Inc.
+ * Copyright (c) 1994-2005 by The XFree86 Project, Inc.
  * All rights reserved.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
@@ -68,8 +68,6 @@
  * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  */
 
-/* $XConsortium: compiler.h /main/16 1996/10/25 15:38:34 kaleb $ */
-
 #ifndef _COMPILER_H
 
 # if !defined(_XF86_ANSIC_H) && defined(XFree86Module)
@@ -172,6 +170,38 @@ extern void stw_brx(unsigned short, volatile unsigned char *, int);
 extern unsigned long ldl_brx(volatile unsigned char *, int);
 extern unsigned short ldw_brx(volatile unsigned char *, int);
 
+#  if (defined(linux) || defined(Lynx) || defined(sun) || defined(__OpenBSD__) || defined(__FreeBSD__)) && defined(__sparc__)
+unsigned char xf86ReadMmio8(__volatile__ void *base,
+			    const unsigned long offset);
+unsigned short xf86ReadMmio16Be(__volatile__ void *base,
+				const unsigned long offset);
+unsigned short xf86ReadMmio16Le(__volatile__ void *base,
+				const unsigned long offset);
+unsigned int xf86ReadMmio32Be(__volatile__ void *base,
+			      const unsigned long offset);
+unsigned int xf86ReadMmio32Le(__volatile__ void *base,
+			      const unsigned long offset);
+void xf86WriteMmio8(__volatile__ void *base, const unsigned long offset,
+		   const unsigned int val);
+void xf86WriteMmio16Be(__volatile__ void *base, const unsigned long offset,
+		       const unsigned int val);
+void xf86WriteMmio16Le(__volatile__ void *base, const unsigned long offset,
+		       const unsigned int val);
+void xf86WriteMmio32Be(__volatile__ void *base, const unsigned long offset,
+		       const unsigned int val);
+void xf86WriteMmio32Le(__volatile__ void *base, const unsigned long offset,
+		       const unsigned int val);
+void xf86WriteMmio8NB(__volatile__ void *base, const unsigned long offset,
+		      const unsigned int val);
+void xf86WriteMmio16BeNB(__volatile__ void *base, const unsigned long offset,
+			 const unsigned int val);
+void xf86WriteMmio16LeNB(__volatile__ void *base, const unsigned long offset,
+			 const unsigned int val);
+void xf86WriteMmio32BeNB(__volatile__ void *base, const unsigned long offset,
+			 const unsigned int val);
+void xf86WriteMmio32LeNB(__volatile__ void *base, const unsigned long offset,
+			 const unsigned int val);
+#  endif /* sparc */
 # endif
 
 # ifndef NO_INLINE
@@ -513,7 +543,7 @@ __ustw (unsigned long r5, unsigned short * r11)
 #    define outw(a,b)	_outw(b,a)
 #    define outl(a,b)	_outl(b,a) 
 
-#   elif defined(linux) && defined(__AMD64__) 
+#   elif defined(linux) && (defined(__amd64__) || defined(__x86_64__))
  
 #    include <inttypes.h>
 
@@ -586,11 +616,18 @@ inl(unsigned short port)
 #      define ASI_PL 0x88
 #     endif
 
-#     define barrier() __asm__ __volatile__(".word 0x8143e00a": : :"memory")
+/*
+ * MEMBAR instruction coded to be acceptable even to an assembler not
+ * expecting it in its input stream.  This has been changed to "membar"
+ * everything and is now used to bracket most accesses for fault-isolation
+ * purposes.
+ */
+#     define barrier() __asm__ __volatile__(".word 0x8143e07f": : :"memory")
 
 static __inline__ void
 outb(unsigned long port, unsigned char val)
 {
+	barrier();
 	__asm__ __volatile__("stba %0, [%1] %2"
 			     : /* No outputs */
 			     : "r" (val), "r" (port), "i" (ASI_PL));
@@ -600,6 +637,7 @@ outb(unsigned long port, unsigned char val)
 static __inline__ void
 outw(unsigned long port, unsigned short val)
 {
+	barrier();
 	__asm__ __volatile__("stha %0, [%1] %2"
 			     : /* No outputs */
 			     : "r" (val), "r" (port), "i" (ASI_PL));
@@ -609,6 +647,7 @@ outw(unsigned long port, unsigned short val)
 static __inline__ void
 outl(unsigned long port, unsigned int val)
 {
+	barrier();
 	__asm__ __volatile__("sta %0, [%1] %2"
 			     : /* No outputs */
 			     : "r" (val), "r" (port), "i" (ASI_PL));
@@ -619,9 +658,12 @@ static __inline__ unsigned int
 inb(unsigned long port)
 {
 	unsigned int ret;
+
+	barrier();
 	__asm__ __volatile__("lduba [%1] %2, %0"
 			     : "=r" (ret)
 			     : "r" (port), "i" (ASI_PL));
+	barrier();
 	return ret;
 }
 
@@ -629,9 +671,12 @@ static __inline__ unsigned int
 inw(unsigned long port)
 {
 	unsigned int ret;
+
+	barrier();
 	__asm__ __volatile__("lduha [%1] %2, %0"
 			     : "=r" (ret)
 			     : "r" (port), "i" (ASI_PL));
+	barrier();
 	return ret;
 }
 
@@ -639,9 +684,12 @@ static __inline__ unsigned int
 inl(unsigned long port)
 {
 	unsigned int ret;
+
+	barrier();
 	__asm__ __volatile__("lda [%1] %2, %0"
 			     : "=r" (ret)
 			     : "r" (port), "i" (ASI_PL));
+	barrier();
 	return ret;
 }
 
@@ -651,9 +699,11 @@ xf86ReadMmio8(__volatile__ void *base, const unsigned long offset)
 	unsigned long addr = ((unsigned long)base) + offset;
 	unsigned char ret;
 
+	barrier();
 	__asm__ __volatile__("lduba [%1] %2, %0"
 			     : "=r" (ret)
 			     : "r" (addr), "i" (ASI_PL));
+	barrier();
 	return ret;
 }
 
@@ -663,9 +713,11 @@ xf86ReadMmio16Be(__volatile__ void *base, const unsigned long offset)
 	unsigned long addr = ((unsigned long)base) + offset;
 	unsigned short ret;
 
+	barrier();
 	__asm__ __volatile__("lduh [%1], %0"
 			     : "=r" (ret)
 			     : "r" (addr));
+	barrier();
 	return ret;
 }
 
@@ -675,9 +727,11 @@ xf86ReadMmio16Le(__volatile__ void *base, const unsigned long offset)
 	unsigned long addr = ((unsigned long)base) + offset;
 	unsigned short ret;
 
+	barrier();
 	__asm__ __volatile__("lduha [%1] %2, %0"
 			     : "=r" (ret)
 			     : "r" (addr), "i" (ASI_PL));
+	barrier();
 	return ret;
 }
 
@@ -687,9 +741,11 @@ xf86ReadMmio32Be(__volatile__ void *base, const unsigned long offset)
 	unsigned long addr = ((unsigned long)base) + offset;
 	unsigned int ret;
 
+	barrier();
 	__asm__ __volatile__("ld [%1], %0"
 			     : "=r" (ret)
 			     : "r" (addr));
+	barrier();
 	return ret;
 }
 
@@ -699,9 +755,11 @@ xf86ReadMmio32Le(__volatile__ void *base, const unsigned long offset)
 	unsigned long addr = ((unsigned long)base) + offset;
 	unsigned int ret;
 
+	barrier();
 	__asm__ __volatile__("lda [%1] %2, %0"
 			     : "=r" (ret)
 			     : "r" (addr), "i" (ASI_PL));
+	barrier();
 	return ret;
 }
 
@@ -711,6 +769,7 @@ xf86WriteMmio8(__volatile__ void *base, const unsigned long offset,
 {
 	unsigned long addr = ((unsigned long)base) + offset;
 
+	barrier();
 	__asm__ __volatile__("stba %0, [%1] %2"
 			     : /* No outputs */
 			     : "r" (val), "r" (addr), "i" (ASI_PL));
@@ -723,6 +782,7 @@ xf86WriteMmio16Be(__volatile__ void *base, const unsigned long offset,
 {
 	unsigned long addr = ((unsigned long)base) + offset;
 
+	barrier();
 	__asm__ __volatile__("sth %0, [%1]"
 			     : /* No outputs */
 			     : "r" (val), "r" (addr));
@@ -735,6 +795,7 @@ xf86WriteMmio16Le(__volatile__ void *base, const unsigned long offset,
 {
 	unsigned long addr = ((unsigned long)base) + offset;
 
+	barrier();
 	__asm__ __volatile__("stha %0, [%1] %2"
 			     : /* No outputs */
 			     : "r" (val), "r" (addr), "i" (ASI_PL));
@@ -747,6 +808,7 @@ xf86WriteMmio32Be(__volatile__ void *base, const unsigned long offset,
 {
 	unsigned long addr = ((unsigned long)base) + offset;
 
+	barrier();
 	__asm__ __volatile__("st %0, [%1]"
 			     : /* No outputs */
 			     : "r" (val), "r" (addr));
@@ -759,6 +821,7 @@ xf86WriteMmio32Le(__volatile__ void *base, const unsigned long offset,
 {
 	unsigned long addr = ((unsigned long)base) + offset;
 
+	barrier();
 	__asm__ __volatile__("sta %0, [%1] %2"
 			     : /* No outputs */
 			     : "r" (val), "r" (addr), "i" (ASI_PL));
@@ -1638,25 +1701,25 @@ extern void outl(unsigned port, unsigned val);
 
 # ifdef __alpha__
 /* entry points for Mmio memory access routines */
-extern int (*xf86ReadMmio8)(void *, unsigned long);
-extern int (*xf86ReadMmio16)(void *, unsigned long);
+extern int (*xf86ReadMmio8)(volatile void *, unsigned long);
+extern int (*xf86ReadMmio16)(volatile void *, unsigned long);
 #  ifndef STANDALONE_MMIO
-extern int (*xf86ReadMmio32)(void *, unsigned long);
+extern int (*xf86ReadMmio32)(volatile void *, unsigned long);
 #  else
 /* Some DRI 3D drivers need MMIO_IN32. */
 static __inline__ int
-xf86ReadMmio32(void *Base, unsigned long Offset)
+xf86ReadMmio32(volatile void *Base, unsigned long Offset)
 {
 	__asm__ __volatile__("mb"  : : : "memory");
 	return *(volatile CARD32*)((unsigned long)Base+(Offset));
 }
 #  endif
-extern void (*xf86WriteMmio8)(int, void *, unsigned long);
-extern void (*xf86WriteMmio16)(int, void *, unsigned long);
-extern void (*xf86WriteMmio32)(int, void *, unsigned long);
-extern void (*xf86WriteMmioNB8)(int, void *, unsigned long);
-extern void (*xf86WriteMmioNB16)(int, void *, unsigned long);
-extern void (*xf86WriteMmioNB32)(int, void *, unsigned long);
+extern void (*xf86WriteMmio8)(int, volatile void *, unsigned long);
+extern void (*xf86WriteMmio16)(int, volatile void *, unsigned long);
+extern void (*xf86WriteMmio32)(int, volatile void *, unsigned long);
+extern void (*xf86WriteMmioNB8)(int, volatile void *, unsigned long);
+extern void (*xf86WriteMmioNB16)(int, volatile void *, unsigned long);
+extern void (*xf86WriteMmioNB32)(int, volatile void *, unsigned long);
 extern void xf86JensenMemToBus(char *, long, long, int);
 extern void xf86JensenBusToMem(char *, char *, unsigned long, int);
 extern void xf86SlowBCopyFromBus(unsigned char *, unsigned char *, int);
@@ -1737,7 +1800,7 @@ extern void xf86SlowBCopyToBus(unsigned char *, unsigned char *, int);
 #  define MMIO_MOVE32(base, offset, val) \
        xf86WriteMmio32Be(base, offset, (CARD32)(val))
 
-static __inline__ void ppc_flush_icache(char *addr)
+static __inline__ void ppc_flush_icache(void *addr)
 {
 	__asm__ volatile (
 		"dcbf 0,%0;" 
