@@ -30,7 +30,7 @@ Author:	Ralph R. Swick, DEC/MIT Project Athena
 	one weekend in November, 1989
 Modified: Mark Leisher <mleisher@crl.nmsu.edu> to deal with UCS sample text.
 */
-/* $XFree86: xc/programs/xfontsel/xfontsel.c,v 1.10 2006/01/09 15:01:09 dawes Exp $ */
+/* $XFree86: xc/programs/xfontsel/xfontsel.c,v 1.11 2007/04/09 15:37:20 tsi Exp $ */
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -987,6 +987,7 @@ Boolean Matches(
     register int field = (*fontName == DELIM) ? -1 : 0;
     register Boolean marked_this_field = False;
 
+    *maxField = 0;
     while (*pattern) {
 	if (*pattern == *fontName || *pattern == '?') {
 	    pattern++;
